# Install
```
pip install sipe
```


# Convert Type

|Name|Mean|
|-|-|
|to_str|..|
|to_int|..|
|to_md5|..|
|to_dict|..|
|to_xml|xpath xml doc|
|to_doc|xpath html doc|

# List Split

|Name |Mean|
|split_int_n|split list into n list|
|slice_by|..|
|group_by_key|group dict by key|

